function handles = GenerateGn_flexure(handles)

lbf2N = 4.448;
lbfin2Nm = 0.1129;
angle_offset = handles.forceinfo.angle_offset;%degrees

%collect constants
V_per_ms2 = handles.controllerinfo.V_per_ms2;

dt = 1/handles.daqinfo.samples_per_second;

rawplatesignals = handles.globalinfo.rawplatesignals;
platesignals = handles.globalinfo.platesignals;

N = handles.daqinfo.cycles_per_update;
Na = handles.daqinfo.num_transient_cycles;
Nb = handles.daqinfo.num_collected_cycles;
Nc = handles.daqinfo.num_processing_cycles;
maxupdates = handles.globalinfo.maxupdates;
errortol = handles.globalinfo.errortol;

Gnfreqs_flexure = handles.flexureinfo.Gnfreqs_flexure;
forcesignals = handles.globalinfo.forcesignals;

%initialize Gn, Gn_raw, and Gn_sp to be zero matrix of proper dimensions 
Gn_flexure = zeros(numel(platesignals), numel(forcesignals), numel(Gnfreqs_flexure));

%initialize f_all matrix to store all force-time info
basefreq = Gnfreqs_flexure(1);
handles.plateinfo.basefreq = basefreq;
w = 2*pi*basefreq;
T = 1/basefreq;
handles.plateinfo.T = T;
t_all = 0:dt:T-dt;
handles.plateinfo.t_all = t_all;
samples_per_cycle = length(t_all);
handles.plateinfo.samples_per_cycle = samples_per_cycle;
handles.flexureinfo.f_all = NaN*zeros(handles.plateinfo.samples_per_cycle, numel(handles.globalinfo.forcesignals),numel(handles.flexureinfo.Gnfreqs_flexure),numel(handles.globalinfo.platesignals)); %4-d matrix with all force data.  dim 1 (columns) = Fx through Mz.  dim 2 (rows) = fft of Fx through Mz for logged number of cycles.  dim-3 = frequencies.  dim-4 = plate inputs

%get matrix converting L to W to frame
A = handles.signalinfo.A;

%get crosstalk matrix for force sensor
crosstalk = handles.forceinfo.crosstalk;
angle_correction = [cosd(angle_offset) -sind(angle_offset)  0;
                    sind(angle_offset)  cosd(angle_offset)  0;
                                     0                   0  1]'; %transpose
    
maxharmonic = handles.controllerinfo.maxharmonic;

Gn = handles.controllerinfo.Gn;
Gnfreqs = handles.controllerinfo.Gnfreqs;

gain = handles.controllerinfo.gain;

controllerupdates_per_plot = 1;

for i = 1:numel(platesignals)

    %update plateinfo
    basefreq = Gnfreqs_flexure(1);
    handles.plateinfo.basefreq = basefreq;
    w = 2*pi*basefreq;
    T = 1/basefreq;
    handles.plateinfo.T = T;
    t_all = 0:dt:T-dt;
    handles.plateinfo.t_all = t_all;
    samples_per_cycle = length(t_all);
    handles.plateinfo.samples_per_cycle = samples_per_cycle;

    %specify how many samples to collect upon trigger
    handles.daqinfo.ai.SamplesPerTrigger = Nb*samples_per_cycle;

    %controlled frequencies
    controlledfreqs = basefreq:basefreq:basefreq*maxharmonic;
    handles.controllerinfo.controlledfreqs = controlledfreqs;

    %get d and u signals
    d = zeros(numel(t_all),numel(platesignals));
    if i <= 3
        d(:,i) = handles.plateinfo.Alin(i)*sin(w*t_all)';
    else
        d(:,i) = handles.plateinfo.Aang(i-3)*sin(w*t_all)';
    end
    handles.signalinfo.d = d;
    u = 0*d;

    %fft Nb cycles of desired plate motion signals
    d_fft = fft(repmat(d,[Nb,1]));

    %fft Nb cycles of u
    u_fft = fft(repmat(u,[Nb,1]));

    %make sure u_fft is zero for frequencies above maxharmonic*basefreq
    maxfftind = (Nb*maxharmonic+1)+1;
    u_fft(maxfftind+1:end-maxfftind+1,:) = 0;

    %determine if initial control signals must change
    tag = get(get(handles.initialcontrol,'selectedobject'),'tag');
    switch tag
        case 'guess'
            for k = 1:numel(controlledfreqs)
                %get indices in fft signals corresponding to current frequency
                fftind = Nb*k + 1;

                %get indices in Gn corresponding to current frequency
                Gnind = find(Gnfreqs == controlledfreqs(k));

                u_fft(fftind,:) = (Gn(:,:,Gnind)\d_fft(fftind,:).').';

                %make sure entries at end of u_fft are conjugates of entries at
                %beginning
                u_fft(end-fftind+2,:) = conj(u_fft(fftind,:));

                %reset u (1 cycle)
                u = ifft(u_fft);
                u = u(1:samples_per_cycle,:);
            end
        case 'zero'
            u = 0*u;
            u_fft = 0*u_fft;
    end


    %create N cycles of u.
    u_ao = repmat(u ,[N,1]);

    %create clock ao signal with trigger just before cycle Na
    clock = 0*u_ao(:,1);
    clock([Na*samples_per_cycle:Na*samples_per_cycle+5]) = 5;

    controllerupdates = 0;
    set(handles.controllerupdates,'string',num2str(controllerupdates))
    set(handles.time_per_update,'string',num2str(handles.daqinfo.cycles_per_update*handles.plateinfo.T))
    set(handles.maxforceharmonic,'string',num2str(handles.forceinfo.maxharmonic))

    j = 1;
    while j <= numel(Gnfreqs_flexure) && get(handles.newGn_flexure,'value')

        set(handles.basefreq,'string',[num2str(basefreq), 'Hz'])
        set(handles.samples_per_cycle,'string',samples_per_cycle)

        %update force signals panel in GUI
        maxpossibleharmonic = floor(handles.plateinfo.samples_per_cycle/2);
        set(handles.maxforceharmonic_text,'string',['Plotted harmonics (max = ',num2str(maxpossibleharmonic),'):'])
        maxforceharmonic = eval(get(handles.maxforceharmonic,'string'));
        if maxforceharmonic > maxpossibleharmonic
            set(handles.maxforceharmonic,'string',num2str(maxpossibleharmonic))
        end

        %specify how many samples to collect upon trigger
        handles.daqinfo.ai.SamplesPerTrigger = Nb*samples_per_cycle;

        %start analog intput device (set to log during trigger event and then stops
        %once data has been logged)
        start(handles.daqinfo.ai)

        %make sure there are still samples left in queue for ao to output. if
        %there are no more samples then the ao device will be "off" and
        %must be restarted.
        if get(handles.daqinfo.ao,'samplesavailable') < samples_per_cycle*(Nb+Nc)
            putdata(handles.daqinfo.ao, [clock u_ao])
            if strcmp(get(handles.daqinfo.ao,'Running'), 'Off')
                start(handles.daqinfo.ao)
            end
        end

        %wait for data to be collected from analog input (the device stops once
        %the data is logged)
        wait(handles.daqinfo.ai,5) %HARD CODED WAIT TIME--MODIFY???

        %import Nb cycles of accelerometer signals.  columns of aidata
        %correspond to ai_channel_names (i.e., sp1, sp2, sp3, sp4, pl1x, pl1y,
        %pl2x, pl2y)
        aidata = 1/V_per_ms2*getdata(handles.daqinfo.ai);

        %subtract offset from data due to (accelerometer) bias
        aidata = aidata - repmat(mean(aidata),[size(aidata,1),1]);

        %put aidata into signal matrices
        y_raw_ai = aidata(:,1:numel(rawplatesignals));
        f_raw_ai = aidata(:,numel(rawplatesignals)+1:end)*V_per_ms2;

        %convert raw acceleration signals in local frames into plate
        %acceleration in W frame
        y_ai =A\y_raw_ai';
        y_ai = y_ai'; %put y_ai back into format where each signal is a column
        
        %convert  forces
        f_ai = (f_raw_ai(:,1:6)-f_raw_ai(:,7:12))*crosstalk;
        f_ai(:,1:3) = lbf2N*f_ai(:,1:3)*angle_correction;
        f_ai(:,4:6) = lbfin2Nm*f_ai(:,4:6)*angle_correction;

        %fft y_ai
        y_fft = fft(y_ai);

        %compute error
        e_fft = d_fft - y_fft;
        
        norm_e_fft = norm(abs(e_fft)./max(abs(d_fft),1));
        set(handles.norme,'string',num2str(norm_e_fft,4))

        %update ffts of control signals.
        for k = 1:numel(controlledfreqs)
            %get indices in fft signals corresponding to current frequency
            fftind = Nb*k + 1;

            %get indices in Gn corresponding to current frequency
            Gnind = find(Gnfreqs == controlledfreqs(k));

            %apply iterative control law at each frequency
            deltau_fft = (Gn(:,:,Gnind)\e_fft(fftind,:).').';
            u_fft(fftind,:) = u_fft(fftind,:) + gain*deltau_fft;

            %make sure entries at end of u_fft are conjugates of entries at
            %beginning
            u_fft(end-fftind+2,:) = conj(u_fft(fftind,:));
        end

        %get u (1 cycle) and u_ao (N cycles)
        u = ifft(u_fft);
        u = u(1:samples_per_cycle,:);

        %check to make sure that u does not exceed saturation voltage.  on
        %indices where it does, replace those voltages with +/-saturation
        %voltage
        signu = sign(u);
        saturation = handles.controllerinfo.saturation*ones(size(u));
        ind = find(abs(u) > saturation);
        u(ind) = signu(ind).*saturation(ind);
        if ~isempty(ind)
            break
        end

        %make N cycles of u to send to analog out.
        u_ao = repmat(u,[N,1]);
        
        %update clock ao signal with trigger just before cycle Na
        clock = 0*u_ao(:,1);
        clock(Na*samples_per_cycle) = 5;

        %put new u_ao into queue
        putdata(handles.daqinfo.ao, [clock u_ao])

        %put signals back into handles
        handles.signalinfo.y = y_ai(1:samples_per_cycle,:);
        handles.signalinfo.y_raw = y_raw_ai(1:samples_per_cycle,:);
        handles.signalinfo.u = u;
        handles.signalinfo.f = f_ai(1:samples_per_cycle,:);
        
        %plot data in GUI
        if mod(controllerupdates,controllerupdates_per_plot) == 0
            PlotControls(handles)
            PlotPlate(handles)
            PlotForces(handles)
        end
        controllerupdates = controllerupdates + 1;
        handles.globalinfo.controllerupdates = controllerupdates;
        set(handles.controllerupdates,'string',num2str(controllerupdates))

        if controllerupdates == maxupdates || norm_e_fft < errortol 
            %fft force data
            f_fft = fft(f_ai);
            
            handles.flexureinfo.f_all(1:samples_per_cycle,:,j,i) = f_ai(1:samples_per_cycle,:);

            %construct Gn_flexure
            ind = Nb+1; %index corresponding to Gnfreqs_flexure(j) in the fft
            Gn_flexure(:,i,j) = f_fft(ind,:)/y_fft(ind,i);

            %update plateinfo if not at highest frequency in
            %Gnfreqs_flexure
            j = j + 1;
            
            if j <= numel(Gnfreqs_flexure)
                basefreq = Gnfreqs_flexure(j);
                handles.plateinfo.basefreq = basefreq;
                w = 2*pi*basefreq;
                T = 1/basefreq;
                handles.plateinfo.T = T;
                t_all = 0:dt:T-dt;
                handles.plateinfo.t_all = t_all;
                samples_per_cycle = length(t_all);
                handles.plateinfo.samples_per_cycle = samples_per_cycle;

                %get d and u signals
                d = zeros(numel(t_all),numel(platesignals));
                if i <= 3
                    d(:,i) = handles.plateinfo.Alin(i)*sin(w*t_all)';
                else
                    d(:,i) = handles.plateinfo.Aang(i-3)*sin(w*t_all)';
                end
                handles.signalinfo.d = d;

                %fft Nb cycles of desired plate motion signals
                d_fft = fft(repmat(d,[Nb,1]));
                
                %fft Nb cycles of u
                u_fft = u_fft(1:Nb*samples_per_cycle,:);
                for k = 1:numel(controlledfreqs)
                    %get indices in fft signals corresponding to current frequency
                    fftind = Nb*k + 1;

                    %make sure entries at end of u_fft are conjugates of entries at
                    %beginning
                    u_fft(end-fftind+2,:) = conj(u_fft(fftind,:));
                end
                
                u = ifft(u_fft);
                u = u(1:samples_per_cycle,:);

                %create N cycles of u.
                u_ao = repmat(u ,[N,1]);

                %create clock ao signal with trigger just before cycle Na
                clock = 0*u_ao(:,1);
                clock(Na*samples_per_cycle) = 5;

                %controlled frequencies
                controlledfreqs = basefreq:basefreq:basefreq*maxharmonic;
                
            end
            controllerupdates = 0;
            set(handles.basefreq,'string',[num2str(basefreq),' Hz'])
            set(handles.time_per_update,'string',num2str(handles.daqinfo.cycles_per_update*handles.plateinfo.T))
        end
    end

    stop(handles.daqinfo.ao)
end

if isfield(handles.flexureinfo,'Gn_flexure')
    handles.flexureinfo.Gn_flexure = Gn_flexure;
end

stop(handles.daqinfo.ai)
stop(handles.daqinfo.ao)

set(handles.newGn_flexure,'value',0,'string','Generate flexure frequency response')
