function handles = Initializedaqinfo(handles)

%get signal names
controlsignals = handles.globalinfo.controlsignals;
rawplatesignals = handles.globalinfo.rawplatesignals;
rawforcesignals = handles.globalinfo.rawforcesignals;

%ao channel names are: clock sp1, sp2, sp3, sp4, sp5, sp6
%ai channel names are: x1dd, y1dd, x2dd, y2dd, x3dd,
%y3dd, x4dd, y4dd, x5dd, y5dd, x6dd, y6dd, Fx, Fy, Fz, Mx, My, Mz
handles.daqinfo.ao_channel_names = ['clock', controlsignals];
handles.daqinfo.ai_channel_names = [rawplatesignals,rawforcesignals];

daqinfo = daqhwinfo;
if ismember('nidaq',daqinfo.InstalledAdaptors)
    %nidaq has been found, so configure daq settings
    if (~isempty(daqfind))
        stop(daqfind)
    end
    daqreset

    %create input and output objects
    handles.daqinfo.ao = analogoutput('nidaq','Dev2');
    handles.daqinfo.ai = analoginput('nidaq','Dev3');
    
    %daq properties
    set(handles.daqinfo.ai,'InputType','SingleEnded')
    set(handles.daqinfo.ai,'TriggerType','HwDigital')
    set(handles.daqinfo.ai,'TriggerCondition','PositiveEdge');

    %set up channels
    addchannel(handles.daqinfo.ao, [0:numel(controlsignals)],[1:numel(controlsignals)+1], handles.daqinfo.ao_channel_names);
    
    %addchannel(handles.daqinfo.ai, [0:11],[1:numel(rawplatesignals)], handles.daqinfo.ai_channel_names);
    addchannel(handles.daqinfo.ai,[0:11,18:23,26:31],[1:numel(rawplatesignals)+numel(rawforcesignals)], handles.daqinfo.ai_channel_names);

    %set sample rates
    handles.daqinfo.ao.SampleRate = handles.daqinfo.samples_per_second;
    handles.daqinfo.ai.SampleRate = handles.daqinfo.samples_per_second;
    
    %set range of input voltages
    handles.daqinfo.ai.Channel.InputRange = [-5, 5];

else
    %no nidaq found

    handles.daqinfo.ao = [];
    handles.daqinfo.ai = [];
    handles.daqinfo.ao.SampleRate = [];
    handles.daqinfo.ai.SampleRate = [];
end
