function PlotGn_flexure(handles)

mainGUIhandles = handles.mainGUIhandles;

platesignals = mainGUIhandles.globalinfo.platesignals;
forcesignals = mainGUIhandles.globalinfo.forcesignals;

Gnfreqs_flexure = mainGUIhandles.flexureinfo.Gnfreqs_flexure;
Gn_flexure = mainGUIhandles.flexureinfo.Gn_flexure;
Gn_flexure_mag = abs(Gn_flexure);
Gn_flexure_phase = angle(Gn_flexure);

%create cell array of plotting options with each panel in GUI
%corresponding to a row and the entries in that panel making up the columns in
%that row
for i = 1:2
    switch i
        case 1 %e.g., pddx --> F
            for j = 1:numel(platesignals)
                plotoptions{i,j} = [platesignals{j},'_2_F'];
            end
        case 2 %e.g., u --> Fx
            for j = 1:numel(forcesignals)
                plotoptions{i,j} = ['u_2_',forcesignals{j}];
            end
    end
end


%get tag of selected radio button in frequency units button panel
frequencyunits = get(get(handles.frequencyunits,'selectedobject'),'tag');
if strcmp(frequencyunits,'Hz')
    freqs = Gnfreqs_flexure; %cyc/s (Hz)
    xlabeltext = 'Frequency (Hz)';
else
    freqs = Gnfreqs_flexure/(2*pi); %rad/s
    xlabeltext = 'Frequency (rad/s)';
end

%get tag of selected radio button in gain units button panel
gainunits = get(get(handles.gainunits,'selectedobject'),'tag');
if strcmp(gainunits,'F_per_acc')
    gain = Gn_flexure_mag;
    ylabeltext = {'gain (N/(m/s^2))','gain (Nm/(m/s^2)','gain (N/(rad/s^2)','gain (Nm/(rad/s^2)'};
else
    gain = 20*log10(Gn_flexure_mag);
    ylabeltext = {'gain (dB)','gain (dB)','gain (dB)','gain (dB)'};
end

%get the plot options block (blocknum) and position within the block (blocknum_ind)
plottype = get(get(handles.plotoptions,'selectedobject'),'tag');

[row col] = size(plotoptions);
for i = 1:row
    for j = 1:col
        if strcmp(plottype, plotoptions{i,j})
            panel = i;
            ind = j;
        end
    end
end


if exist('panel')

    switch panel
        case 1 %panel 1: %e.g., pddx --> F (1 input --> 6 outputs)
            gainslice = squeeze(gain(:,ind,:));
            Fmin = min(min(min(gainslice(1:3,:))),0);
            Fmax = max(max(max(gainslice(1:3,:))),0);
            Mmin = min(min(min(gainslice(4:6,:))),0);
            Mmax = max(max(max(gainslice(4:6,:))),0);

            for i = 1:numel(forcesignals)
                %gain plots
                eval(['axes(handles.axes',num2str(2*i-1),')'])
                stem(freqs, gainslice(i,:))
                set(gca,'xlim',[0 Gnfreqs_flexure(end)+10])
                if i <= 3
                    set(gca,'ylim',[1.1*Fmin 1.1*Fmax])
                    if i == 1
                        if ind <= 3
                            ylabel(ylabeltext{1})
                        else
                            ylabel(ylabeltext{3})
                        end
                    end
                else
                    set(gca,'ylim',[1.1*Mmin 1.1*Mmax])
                    if i == 4
                        if ind <= 3
                            ylabel(ylabeltext{2})
                        else
                            ylabel(ylabeltext{4})
                        end
                    end
                end
                if strcmp(frequencyunits,'rad_per_s')
                    set(gca,'Xscale','log')
                end
                title([platesignals{ind},' --> ',forcesignals{i}])

                %phase plots
                eval(['axes(handles.axes',num2str(2*i),')'])
                stem(freqs, unwrap(squeeze(Gn_flexure_phase(i,ind,:))))
                set(gca,'xlim',[0 Gnfreqs_flexure(end)+10])
                if strcmp(frequencyunits,'rad_per_s')
                    set(gca,'Xscale','log')
                end
                set(gca,'ylim',[1.5*-2*pi,1.5*2*pi])
                set(gca,'ytick',[-2*pi:pi:2*pi])
                if i == 1
                    xlabel(xlabeltext)
                    ylabel('phase (rad)')
                end
            end

        case 2 %panel 2: %e.g., u --> F1 (6 inputs --> 1 output)
            gainslice = squeeze(gain(ind,:,:));
            Fmin = min(min(min(gainslice(1:6,:))),0);
            Fmax = max(max(max(gainslice(1:6,:))),0);
            Mmin = Fmin;
            Mmax = Fmax;

            for i = 1:numel(platesignals)
                %gain plots
                eval(['axes(handles.axes',num2str(2*i-1),')'])
                stem(freqs, gainslice(i,:))
                set(gca,'xlim',[0 Gnfreqs_flexure(end)+10])
                if i <= 3
                    set(gca,'ylim',[1.1*Fmin 1.1*Fmax])
                    if i == 1
                        if ind <= 3
                            ylabel(ylabeltext{1})
                        else
                            ylabel(ylabeltext{2})
                        end
                    end
                else
                    set(gca,'ylim',[1.1*Mmin 1.1*Mmax])
                    if i == 4
                        if ind <= 3
                            ylabel(ylabeltext{3})
                        else
                            ylabel(ylabeltext{4})
                        end
                    end
                end
                if strcmp(frequencyunits,'rad_per_s')
                    set(gca,'Xscale','log')
                end
                title([platesignals{i},' --> ',forcesignals{ind}])

                %phase plots
                eval(['axes(handles.axes',num2str(2*i),')'])
                stem(freqs, unwrap(squeeze(Gn_flexure_phase(ind,i,:))))
                set(gca,'xlim',[0 Gnfreqs_flexure(end)+10])
                if strcmp(frequencyunits,'rad_per_s')
                    set(gca,'Xscale','log')
                end
                set(gca,'ylim',[-1.5*2*pi,1.5*2*pi])
                set(gca,'ytick',[-2*pi:pi:2*pi])
                if i == 1
                    xlabel(xlabeltext)
                    ylabel('phase (rad)')
                end
            end
    end
end
